@@ -1,15 +1,17 @@
 import {
 	queryOptions,
+	useMutation,
 	useQuery,
 	useQueryClient,
 	useSuspenseQuery,
 } from "@tanstack/react-query";
 import { createFileRoute } from "@tanstack/react-router";
-import { ChevronDown, CircleX, Ellipsis } from "lucide-react";
+import { ChevronDown, CircleX, Ellipsis, Star } from "lucide-react";
 import type React from "react";
-import { Suspense, useId, useState } from "react";
+import { Suspense, useId, useMemo, useState } from "react";
 import { HeadingPageName } from "@/app/_main/packages/-tab-selector";
 import Loading from "@/app/-loading";
+import { FavoriteStarToggleButton } from "@/components/FavoriteStarButton";
 import { HNavBar, VStack } from "@/components/layout";
 import { Overlay } from "@/components/Overlay";
 import {
@@ -17,6 +19,11 @@ import {
 	useReorderableList,
 } from "@/components/ReorderableList";
 import { ScrollableCardTable } from "@/components/ScrollableCardTable";
+import { TemplateSelect } from "@/components/TemplateSelect";
+import {
+	type AutoCompleteOption,
+	Autocomplete,
+} from "@/components/ui/autocomplete";
 import { Button } from "@/components/ui/button";
 import {
 	DialogDescription,
@@ -30,13 +37,6 @@ import {
 	DropdownMenuTrigger,
 } from "@/components/ui/dropdown-menu";
 import { Input } from "@/components/ui/input";
-import {
-	Select,
-	SelectContent,
-	SelectItem,
-	SelectTrigger,
-	SelectValue,
-} from "@/components/ui/select";
 import {
 	Tooltip,
 	TooltipContent,
@@ -46,6 +46,7 @@ import {
 	commands,
 	type TauriAlcomTemplate,
 	type TauriProjectTemplateInfo,
+	type TauriVersion,
 } from "@/lib/bindings";
 import { dateToString, formatDateOffset } from "@/lib/dateToString";
 import { type DialogContext, openSingleDialog } from "@/lib/dialog";
@@ -53,12 +54,14 @@ import { tc } from "@/lib/i18n";
 import { processResult } from "@/lib/import-templates";
 import { usePrevPathName } from "@/lib/prev-page";
 import {
+	type ProjectTemplateCategory,
 	projectTemplateCategory,
 	projectTemplateDisplayId,
 	projectTemplateName,
 } from "@/lib/project-template";
 import { toastSuccess, toastThrownError } from "@/lib/toast";
 import { cn } from "@/lib/utils";
+import { compareVersion } from "@/lib/version";
 
 export const Route = createFileRoute("/_main/packages/templates/")({
 	component: RouteComponent,
@@ -81,15 +84,15 @@ function RouteComponent() {
 	return (
 		<VStack>
 			<HNavBar
-				className={"shrink-0"}
+				className="shrink-0"
 				leading={<HeadingPageName pageType={"/packages/templates"} />}
 				trailing={
 					<DropdownMenu>
 						<div className={"flex divide-x"}>
-							<CreateTemplateButton className={"rounded-r-none"} />
+							<CreateTemplateButton className={"rounded-r-none compact:h-10"} />
 							<DropdownMenuTrigger
 								asChild
-								className={"rounded-l-none pl-2 pr-2"}
+								className={"rounded-l-none pl-2 pr-2 compact:h-10"}
 							>
 								<Button>
 									<ChevronDown className={"w-4 h-4"} />
@@ -139,6 +142,7 @@ function TemplatesTableBody() {
 			await openSingleDialog(TemplateEditor, {
 				templates: information.data.templates,
 				template: { ...alcomTemplate, id },
+				favoriteTemplates: information.data.favorite_templates,
 			});
 		} catch (e) {
 			console.error(e);
@@ -161,16 +165,45 @@ function TemplatesTableBody() {
 		}
 	};
 
+	const templatesOrdered = useMemo(() => {
+		const perCategoryFav: {
+			[K in `${boolean}-${ProjectTemplateCategory}`]: TauriProjectTemplateInfo[];
+		} = {
+			"true-builtin": [],
+			"false-builtin": [],
+			"true-alcom": [],
+			"false-alcom": [],
+			"true-vcc": [],
+			"false-vcc": [],
+		};
+		for (const template of information.data.templates) {
+			const category = projectTemplateCategory(template.id);
+			const favorite = information.data.favorite_templates.includes(
+				template.id,
+			);
+			perCategoryFav[`${favorite}-${category}`].push(template);
+		}
+		return (["builtin", "alcom", "vcc"] as const).flatMap((category) => [
+			...perCategoryFav[`true-${category}`],
+			...perCategoryFav[`false-${category}`],
+		]);
+	}, [information.data.templates, information.data.favorite_templates]);
+
 	return (
 		<>
 			<thead>
 				<tr>
+					<th
+						className={`sticky top-0 z-10 border-b border-primary bg-secondary text-secondary-foreground px-2.5 py-1.5`}
+					>
+						<Star className={"size-4"} />
+					</th>
 					{TABLE_HEAD.map((head, index) => (
 						<th
 							// biome-ignore lint/suspicious/noArrayIndexKey: static array
 							key={index}
 							className={
-								"sticky top-0 z-10 border-b border-primary bg-secondary text-secondary-foreground p-2.5"
+								"sticky top-0 z-10 border-b border-primary bg-secondary text-secondary-foreground px-2.5 py-1.5"
 							}
 						>
 							<small className="font-normal leading-none">{tc(head)}</small>
@@ -179,12 +212,13 @@ function TemplatesTableBody() {
 				</tr>
 			</thead>
 			<tbody>
-				{information.data.templates.map((template) => (
+				{templatesOrdered.map((template) => (
 					<TemplateRow
 						key={template.id}
 						template={template}
 						remove={removeTemplate}
 						edit={editTemplate}
+						favorite={information.data.favorite_templates.includes(template.id)}
 					/>
 				))}
 			</tbody>
@@ -196,12 +230,14 @@ function TemplateRow({
 	template,
 	remove,
 	edit,
+	favorite,
 }: {
 	template: TauriProjectTemplateInfo;
 	remove?: (id: string) => void;
 	edit?: (id: string) => void;
+	favorite: boolean;
 }) {
-	const cellClass = "p-2.5";
+	const cellClass = "p-2.5 compact:py-1";
 	const id = useId();
 
 	const category = projectTemplateCategory(template.id);
@@ -218,8 +254,64 @@ function TemplateRow({
 		}
 	};
 
+	const queryClient = useQueryClient();
+
+	const setTemplateFavorite = useMutation({
+		mutationFn: (params: { id: string; favorite: boolean }) =>
+			commands.environmentSetTemplateFavorite(params.id, params.favorite),
+
+		onMutate: async (params) => {
+			await queryClient.cancelQueries(environmentProjectCreationInformation);
+
+			const previousData = queryClient.getQueryData(
+				environmentProjectCreationInformation.queryKey,
+			);
+
+			if (previousData !== undefined) {
+				queryClient.setQueryData(
+					environmentProjectCreationInformation.queryKey,
+					{
+						...previousData,
+						favorite_templates: params.favorite
+							? previousData.favorite_templates.includes(params.id)
+								? previousData.favorite_templates
+								: [...previousData.favorite_templates, params.id]
+							: previousData.favorite_templates.filter((x) => x !== params.id),
+					},
+				);
+			}
+
+			return previousData;
+		},
+
+		onError: (error, _, context) => {
+			console.error("Error favoriting project", error);
+			toastThrownError(error);
+			if (context) {
+				queryClient.setQueryData(
+					environmentProjectCreationInformation.queryKey,
+					context,
+				);
+			}
+		},
+	});
+
 	return (
-		<tr className="even:bg-secondary/30">
+		<tr className="even:bg-secondary/30 group">
+			<td className={`${cellClass} w-3`}>
+				<div className={"relative flex"}>
+					<FavoriteStarToggleButton
+						favorite={favorite}
+						disabled={category === "vcc"}
+						onToggle={() =>
+							setTemplateFavorite.mutate({
+								id: template.id,
+								favorite: !favorite,
+							})
+						}
+					/>
+				</div>
+			</td>
 			<td className={`${cellClass} w-full`}>
 				<label htmlFor={id}>
 					<p className="font-normal">{projectTemplateName(template)}</p>
@@ -416,6 +508,7 @@ function CreateTemplateButton({ className }: { className: string }) {
 					void openSingleDialog(TemplateEditor, {
 						templates: information.data.templates,
 						template: null,
+						favoriteTemplates: information.data.favorite_templates,
 					});
 				}
 			}}
@@ -431,18 +524,25 @@ const prereleaseSegment = regexp`(?:0|[1-9]\d*|[0-9a-z-]*[a-z-][0-9a-z-]*)`;
 const prerelease = regexp`(?:-?${prereleaseSegment}(?:\.${prereleaseSegment})*)`;
 const buildSegment = regexp`(?:[0-9a-z-]+)`;
 const build = regexp`(?:${buildSegment}(?:\.${buildSegment})*)`;
-const rangeRegex = new RegExp(
+const packageRangeRegex = new RegExp(
 	regexp`^\s*(?:(?:>|<|>=|<=|=|\^|~)\s*)?v?${versionSegment}(?:\.${versionSegment}(?:\.${versionSegment}${prerelease}?${build}?)?)?\s*$`,
 	"i",
 );
+// Currently, the unity version channel part and increment part is ignored and not allowed to include
+const unityRangeRegex = new RegExp(
+	regexp`^\s*(?:(?:>|<|>=|<=|=|\^|~)\s*)?v?${versionSegment}(?:\.${versionSegment}(?:\.${versionSegment})?)?\s*$`,
+	"i",
+);
 
 function TemplateEditor({
 	templates,
 	template,
+	favoriteTemplates,
 	dialog,
 }: {
 	templates: TauriProjectTemplateInfo[];
 	template: (TauriAlcomTemplate & { id: string }) | null;
+	favoriteTemplates: string[];
 	dialog: DialogContext<boolean>;
 }) {
 	const [baseTemplate, setBaseTemplate] = useState<string>(
@@ -451,6 +551,183 @@ function TemplateEditor({
 	const [name, setName] = useState(template?.display_name ?? "");
 	const [unityRange, setUnityRange] = useState(template?.unity_version ?? "");
 
+	const allPackages = useQuery({
+		queryKey: ["environmentPackages"],
+		queryFn: () => commands.environmentPackages(),
+	});
+
+	const { packageCandidates, versionCandidatePerPackage } = useMemo(() => {
+		type PackageInfo = {
+			dataSourceVersion: TauriVersion;
+			displayName: string | null;
+			keywords: string[];
+			versions: TauriVersion[];
+		};
+		const packages = new Map<string, PackageInfo>();
+		for (const pkg of allPackages.data ?? []) {
+			if (pkg.is_yanked) continue;
+			let rowInfo = packages.get(pkg.name);
+			if (
+				rowInfo == null ||
+				compareVersion(pkg.version, rowInfo.dataSourceVersion) > 0
+			) {
+				packages.set(
+					pkg.name,
+					(rowInfo = {
+						dataSourceVersion: pkg.version,
+						displayName: pkg.display_name,
+						keywords: pkg.keywords,
+						versions: rowInfo?.versions ?? [],
+					}),
+				);
+			}
+			rowInfo.versions.push(pkg.version);
+		}
+		return {
+			packageCandidates: Array.from(packages.entries()).map(
+				([id, pkg]) =>
+					({
+						value: id,
+						label: (
+							<AutocompletePackageLabel displayName={pkg.displayName} id={id} />
+						),
+						keywords: [pkg.displayName, ...pkg.keywords].filter(
+							(x) => x != null,
+						),
+					}) satisfies AutoCompleteOption,
+			),
+			versionCandidatePerPackage: new Map(
+				Array.from(packages.entries()).map(([id, pkg]) => {
+					// we generate few candidates for version per package
+					// - '*' for any version
+					// - '>=latestStable' and '>=latestPrerelease'
+					// - '^latestStable' and '^latestPrerelease'
+					// - '1.x' '1.2.x' (or something like this) for stable release
+
+					const latestStable = pkg.versions
+						.filter((x) => x.pre === "")
+						.sort(compareVersion)
+						.at(-1);
+					const latestPrerelease = pkg.versions.sort(compareVersion).at(-1);
+
+					const candidates: AutoCompleteOption[] = [];
+
+					function addCandidate(value: string, description: React.ReactNode) {
+						candidates.push({
+							value,
+							label: (
+								<AutocompleteVersionLabel
+									value={value}
+									description={description}
+								/>
+							),
+						});
+					}
+
+					addCandidate("*", tc("templates:dialog:any version"));
+
+					if (latestStable != null) {
+						addCandidate(
+							`${latestStable.major}.x`,
+							`${latestStable.major}.0.0 ≤ v < ${latestStable.major + 1}.0.0`,
+						);
+						addCandidate(
+							`${latestStable.major}.${latestStable.minor}.x`,
+							`${latestStable.major}.${latestStable.minor}.0 ≤ v < ${latestStable.major}.${latestStable.minor + 1}.0`,
+						);
+						addCandidate(
+							`${latestStable.major}.${latestStable.minor}.${latestStable.patch}`,
+							`v = ${latestStable.major}.${latestStable.minor}.${latestStable.patch}`,
+						);
+						addCandidate(
+							`>=${latestStable.major}.${latestStable.minor}.${latestStable.patch}`,
+							`v ≥ ${latestStable.major}.${latestStable.minor}.${latestStable.patch}`,
+						);
+						addCandidate(
+							`^${latestStable.major}.${latestStable.minor}.${latestStable.patch}`,
+							`${latestStable.major}.${latestStable.minor}.${latestStable.patch} ≤ v < ${hatEndVersion(latestStable)}`,
+						);
+					}
+
+					if (latestPrerelease != null && latestPrerelease !== latestStable) {
+						addCandidate(
+							`${latestPrerelease.major}.${latestPrerelease.minor}.${latestPrerelease.patch}-${latestPrerelease.pre}`,
+							`v = ${latestPrerelease.major}.${latestPrerelease.minor}.${latestPrerelease.patch}-${latestPrerelease.pre}`,
+						);
+						addCandidate(
+							`>=${latestPrerelease.major}.${latestPrerelease.minor}.${latestPrerelease.patch}-${latestPrerelease.pre}`,
+							`v ≥ ${latestPrerelease.major}.${latestPrerelease.minor}.${latestPrerelease.patch}-${latestPrerelease.pre}`,
+						);
+						addCandidate(
+							`^${latestPrerelease.major}.${latestPrerelease.minor}.${latestPrerelease.patch}-${latestPrerelease.pre}`,
+							`${latestPrerelease.major}.${latestPrerelease.minor}.${latestPrerelease.patch}-${latestPrerelease.pre} ≤ v < ${hatEndVersion(latestPrerelease)}`,
+						);
+					}
+
+					function hatEndVersion(version: TauriVersion): string {
+						return version.major === 0 && version.minor === 0
+							? `${version.major}.${version.minor}.${version.patch + 1}`
+							: version.major === 0
+								? `${version.major}.${version.minor + 1}.0`
+								: `${version.major + 1}.0.0`;
+					}
+
+					return [id, candidates];
+				}),
+			),
+		};
+	}, [allPackages.data]);
+
+	const unityCandidates = useMemo(() => {
+		const templateInfo = templates.find((x) => x.id === baseTemplate);
+		if (templateInfo == null) return [];
+		// unityVersions is in order
+		// currently, ignore the unity version channel part and increment part
+		const unityVersions = templateInfo.unity_versions.map(
+			(x) => x.split(/[^\d.]/, 2)[0],
+		);
+		const candidates: AutoCompleteOption[] = [];
+
+		function addCandidate(value: string, description: React.ReactNode) {
+			candidates.push({
+				value,
+				label: (
+					<AutocompleteVersionLabel value={value} description={description} />
+				),
+			});
+		}
+
+		candidates.push(...unityVersions);
+
+		addCandidate("*", tc("templates:dialog:any version"));
+
+		// create something like 2022.x and 2022.3.x
+		const addedRange = new Set<string>();
+		for (const unityVersion of unityVersions) {
+			const majorOnly = unityVersion.match(/^\d+/)?.[0];
+			const minor = unityVersion.match(/^\d+\.\d+/)?.[0];
+			if (majorOnly && !addedRange.has(majorOnly)) {
+				addedRange.add(majorOnly);
+				addCandidate(
+					`${majorOnly}.x`,
+					tc("templates:dialog:any unity specified version", {
+						version: majorOnly,
+					}),
+				);
+			}
+			if (minor && !addedRange.has(minor)) {
+				addedRange.add(minor);
+				addCandidate(
+					`${minor}.x`,
+					tc("templates:dialog:any unity specified version", {
+						version: minor,
+					}),
+				);
+			}
+		}
+		return candidates;
+	}, [templates, baseTemplate]);
+
 	type Package = { name: string; range: string };
 	const packagesListContext = useReorderableList<Package>({
 		defaultValue: { name: "", range: "" },
@@ -510,10 +787,10 @@ function TemplateEditor({
 
 	const validVersion = (p: Package) =>
 		(p.name === "" && p.range === "") || // the empty (non-set) row
-		(p.name !== "" && p.range.match(rangeRegex)); // ready to create
+		(p.name !== "" && p.range.match(packageRangeRegex)); // ready to create
 	const readyToCreate =
 		packagesListContext.value.every(validVersion) &&
-		unityRange.match(rangeRegex) &&
+		unityRange.match(unityRangeRegex) &&
 		name.length !== 0;
 
 	return (
@@ -555,25 +832,14 @@ function TemplateEditor({
 										{tc("templates:dialog:base template")}:
 									</th>
 									<td className={"flex"}>
-										<Select
+										<TemplateSelect
 											value={baseTemplate}
 											onValueChange={setBaseTemplate}
-										>
-											<SelectTrigger>
-												<SelectValue className={"grow"} />
-											</SelectTrigger>
-											<SelectContent>
-												{templates.map((template) => {
-													const id = projectTemplateDisplayId(template.id);
-													if (id == null) return null;
-													return (
-														<SelectItem key={id} value={id}>
-															{projectTemplateName(template)}
-														</SelectItem>
-													);
-												})}
-											</SelectContent>
-										</Select>
+											templates={templates}
+											favoriteTemplates={favoriteTemplates}
+											className={"grow"}
+											excludeNoIdTemplates
+										/>
 									</td>
 								</tr>
 								<tr className={"contents"}>
@@ -581,15 +847,15 @@ function TemplateEditor({
 										{tc("templates:dialog:unity version")}:
 									</th>
 									<td className={"flex"}>
-										<Input
+										<Autocomplete
 											className={cn(
 												"grow",
-												unityRange.match(rangeRegex) ||
+												unityRange.match(unityRangeRegex) ||
 													"border-destructive ring-destructive text-destructive",
 											)}
 											value={unityRange}
-											onChange={(e) => setUnityRange(e.target.value)}
-											placeholder={">=2022 * =2022.3.22"}
+											onChange={(value) => setUnityRange(value)}
+											options={unityCandidates}
 										/>
 									</td>
 								</tr>
@@ -620,14 +886,14 @@ function TemplateEditor({
 											<>
 												<td>
 													<div className={"flex"}>
-														<Input
-															type={"text"}
+														<Autocomplete
 															value={value.name}
 															className={"grow"}
-															onChange={(e) =>
+															options={packageCandidates}
+															onChange={(value) =>
 																packagesListContext.update(id, (old) => ({
 																	...old,
-																	name: e.target.value,
+																	name: value,
 																}))
 															}
 														/>
@@ -635,18 +901,20 @@ function TemplateEditor({
 												</td>
 												<td>
 													<div className={"flex"}>
-														<Input
-															type={"text"}
+														<Autocomplete
 															value={value.range}
 															className={cn(
 																"grow",
 																validVersion(value) ||
 																	"border-destructive ring-destructive text-destructive",
 															)}
-															onChange={(e) =>
+															options={
+																versionCandidatePerPackage.get(value.name) ?? []
+															}
+															onChange={(value) =>
 																packagesListContext.update(id, (old) => ({
 																	...old,
-																	range: e.target.value,
+																	range: value,
 																}))
 															}
 														/>
@@ -714,3 +982,34 @@ function TemplateEditor({
 		</div>
 	);
 }
+
+function AutocompletePackageLabel({
+	displayName,
+	id,
+}: {
+	displayName: string | null;
+	id: string;
+}) {
+	if (displayName == null) return id;
+	return (
+		<div className={"flex flex-col"}>
+			<div>{displayName}</div>
+			<div className={"text-xs text-muted-foreground"}>{id}</div>
+		</div>
+	);
+}
+
+function AutocompleteVersionLabel({
+	value,
+	description,
+}: {
+	value: string;
+	description: React.ReactNode;
+}) {
+	return (
+		<div className={"flex flex-row justify-between w-full"}>
+			<div>{value}</div>
+			<div className={"text-xs text-muted-foreground"}>{description}</div>
+		</div>
+	);
+}
