@@ -1,7 +1,6 @@
 import { CircleHelp, CircleUserRound, Ellipsis, Globe } from "lucide-react";
 import {
 	ButtonDisabledIfInvalid,
-	FavoriteToggleButton,
 	getProjectDisplayInfo,
 	ManageOrMigrateButton,
 	ProjectContext,
@@ -11,6 +10,7 @@ import {
 } from "@/app/_main/projects/-project-row";
 import { copyProject } from "@/app/_main/projects/manage/-copy-project";
 import { BackupProjectDialog } from "@/components/BackupProjectDialog";
+import { FavoriteStarToggleButton } from "@/components/FavoriteStarButton";
 import { OpenUnityButton } from "@/components/OpenUnityButton";
 import { RemoveProjectDialog } from "@/components/RemoveProjectDialog";
 import { Button } from "@/components/ui/button";
@@ -55,11 +55,11 @@ export function ProjectGridItem({
 		<ProjectContext.Provider
 			value={{ removed, is_valid, loading: Boolean(loading) }}
 		>
-			<Card className="relative p-4 bg-card flex flex-col gap-2 group">
+			<Card className="relative p-4 bg-card flex flex-col gap-2 group compact:p-2 compact:pl-3 compact:gap-1">
 				<div className={"absolute top-2 right-2 gap-2 flex"}>
 					<div className="relative content-center">
-						<FavoriteToggleButton
-							project={project}
+						<FavoriteStarToggleButton
+							favorite={project.favorite}
 							disabled={removed || loading}
 							onToggle={() =>
 								setProjectFavorite.mutate({
@@ -122,14 +122,7 @@ export function ProjectGridItem({
 									<p className="font-normal whitespace-pre overflow-ellipsis overflow-hidden">
 										{project.name}
 									</p>
-								</TooltipTriggerIfValid>
-								<TooltipContent>{project.name}</TooltipContent>
-							</Tooltip>
-							<Tooltip>
-								<TooltipTriggerIfValid
-									className={"text-left select-text cursor-auto w-full"}
-								>
-									<p className="font-normal opacity-50 text-sm whitespace-pre overflow-ellipsis overflow-hidden">
+									<p className="font-normal opacity-50 text-sm whitespace-pre overflow-ellipsis overflow-hidden compact:hidden">
 										{project.path}
 									</p>
 								</TooltipTriggerIfValid>
@@ -190,7 +183,7 @@ export function ProjectGridItem({
 					</Tooltip>
 				</div>
 
-				<div className="mt-2 flex flex-wrap gap-2 justify-end">
+				<div className="mt-2 flex flex-wrap gap-2 justify-end compact:gap-1">
 					<ButtonDisabledIfInvalid asChild>
 						<OpenUnityButton
 							projectPath={project.path}
