@@ -12,7 +12,7 @@ import { useRef, useState } from "react";
 import { createProject } from "@/app/_main/projects/-create-project";
 import { ProjectsGridCard } from "@/app/_main/projects/-projects-grid-card";
 import Loading from "@/app/-loading";
-import { HNavBar, VStack } from "@/components/layout";
+import { HNavBar, HNavBarText, VStack } from "@/components/layout";
 import { SearchBox } from "@/components/SearchBox";
 import { Button } from "@/components/ui/button";
 import { Card } from "@/components/ui/card";
@@ -188,15 +188,14 @@ function ProjectViewHeader({
 
 	return (
 		<HNavBar
-			className={"shrink-0"}
+			className="shrink-0"
 			leading={
 				<>
-					<p className="cursor-pointer font-bold grow-0 whitespace-pre mb-0 leading-tight">
-						{tc("projects")}
-					</p>
+					<HNavBarText>{tc("projects")}</HNavBarText>
 					<Tooltip>
 						<TooltipTrigger asChild>
 							<Button
+								className={"compact:h-10 compact:w-10"}
 								variant={"ghost"}
 								size={"icon"}
 								onClick={() =>
@@ -215,13 +214,14 @@ function ProjectViewHeader({
 					</Tooltip>
 
 					<SearchBox
-						className={"w-max grow"}
+						className={"w-max grow compact:h-10"}
 						value={search}
 						onChange={(e) => setSearch(e.target.value)}
 						ref={searchRef}
 					/>
 
 					<Button
+						className={"compact:h-10"}
 						variant={"ghost"}
 						onClick={() => {
 							if (viewMode === "List") {
@@ -254,12 +254,15 @@ function ProjectViewHeader({
 				<DropdownMenu>
 					<div className={"flex divide-x"}>
 						<Button
-							className={"rounded-r-none pl-4 pr-3"}
+							className={"rounded-r-none pl-4 pr-3 compact:h-10"}
 							onClick={startCreateProject}
 						>
 							{tc("projects:create new project")}
 						</Button>
-						<DropdownMenuTrigger asChild className={"rounded-l-none pl-2 pr-2"}>
+						<DropdownMenuTrigger
+							asChild
+							className={"rounded-l-none pl-2 pr-2 compact:h-10"}
+						>
 							<Button>
 								<ChevronDown className={"w-4 h-4"} />
 							</Button>
