@@ -1,10 +1,27 @@
 "use client";
 
+import {
+	queryOptions,
+	type UseQueryResult,
+	useIsMutating,
+	useMutation,
+	useQueries,
+	useQuery,
+	useQueryClient,
+} from "@tanstack/react-query";
+import {
+	createFileRoute,
+	useNavigate,
+	useRouter,
+} from "@tanstack/react-router";
+import { ArrowLeft, ChevronDown } from "lucide-react";
+import type React from "react";
+import { Suspense, useMemo } from "react";
 import { copyProject } from "@/app/_main/projects/manage/-copy-project";
 import { BackupProjectDialog } from "@/components/BackupProjectDialog";
+import { HNavBar, VStack } from "@/components/layout";
 import { OpenUnityButton } from "@/components/OpenUnityButton";
 import { RemoveProjectDialog } from "@/components/RemoveProjectDialog";
-import { HNavBar, VStack } from "@/components/layout";
 import { Button } from "@/components/ui/button";
 import { Card } from "@/components/ui/card";
 import {
@@ -44,23 +61,6 @@ import { tc } from "@/lib/i18n";
 import { nameFromPath } from "@/lib/os";
 import { toastSuccess, toastThrownError } from "@/lib/toast";
 import { compareUnityVersionString, parseUnityVersion } from "@/lib/version";
-import {
-	type UseQueryResult,
-	queryOptions,
-	useIsMutating,
-	useMutation,
-	useQueries,
-	useQuery,
-	useQueryClient,
-} from "@tanstack/react-query";
-import {
-	createFileRoute,
-	useNavigate,
-	useRouter,
-} from "@tanstack/react-router";
-import { ArrowLeft, ChevronDown } from "lucide-react";
-import type React from "react";
-import { Suspense, useMemo } from "react";
 import { combinePackagesAndProjectDetails } from "./-collect-package-row-info";
 import { PackageListCard } from "./-package-list-card";
 import { PageContextProvider } from "./-page-context";
@@ -202,7 +202,7 @@ function PageBody() {
 		<PageContextProvider value={pageContext}>
 			<VStack>
 				<ProjectViewHeader
-					className={"shrink-0"}
+					className="shrink-0"
 					isLoading={isLoading}
 					detailsResult={detailsResult}
 					unityVersionsResult={unityVersionsResult}
@@ -309,7 +309,7 @@ function UnityVersionSelector({
 			value={detailsResult.data?.unity_str ?? undefined}
 			onValueChange={requestChangeUnityVersion}
 		>
-			<SelectTrigger>
+			<SelectTrigger className={"compact:h-10"}>
 				{detailsResult.status === "success" ? (
 					(detailsResult.data.unity_str ?? "unknown")
 				) : (
@@ -323,17 +323,13 @@ function UnityVersionSelector({
 	);
 }
 
-function SuggestResolveProjectCard({
-	disabled,
-}: {
-	disabled?: boolean;
-}) {
+function SuggestResolveProjectCard({ disabled }: { disabled?: boolean }) {
 	const { projectPath } = Route.useSearch();
 	const packageChange = useMutation(applyChangesMutation(projectPath));
 
 	return (
-		<Card className={"shrink-0 p-2 flex flex-row items-center"}>
-			<p className="cursor-pointer py-1.5 font-bold grow-0 shrink overflow-hidden whitespace-normal text-sm">
+		<Card className={"shrink-0 p-2 flex flex-row items-center compact:p-1"}>
+			<p className="cursor-pointer py-1.5 font-bold grow-0 shrink overflow-hidden whitespace-normal text-sm pl-2">
 				{tc("projects:manage:suggest resolve")}
 			</p>
 			<div className={"grow shrink-0 w-2"} />
@@ -435,7 +431,7 @@ function SuggestMigrateTo2022Card({
 	onMigrateRequested: () => void;
 }) {
 	return (
-		<Card className={"shrink-0 p-2 flex flex-row items-center"}>
+		<Card className={"shrink-0 p-2 flex flex-row items-center compact:p-1"}>
 			<p className="cursor-pointer py-1.5 font-bold grow-0 shrink overflow-hidden whitespace-normal text-sm pl-2">
 				{tc("projects:manage:suggest unity migration")}
 			</p>
@@ -459,7 +455,7 @@ function Suggest2022PatchMigrationCard({
 	onMigrateRequested: () => void;
 }) {
 	return (
-		<Card className={"shrink-0 p-2 flex flex-row items-center"}>
+		<Card className={"shrink-0 p-2 flex flex-row items-center compact:p-1"}>
 			<p className="cursor-pointer py-1.5 font-bold grow-0 shrink overflow-hidden whitespace-normal text-sm pl-2">
 				{tc("projects:manage:suggest unity patch migration")}
 			</p>
@@ -483,7 +479,7 @@ function SuggestChinaToInternationalMigrationCard({
 	onMigrateRequested: () => void;
 }) {
 	return (
-		<Card className={"shrink-0 p-2 flex flex-row items-center"}>
+		<Card className={"shrink-0 p-2 flex flex-row items-center compact:p-1"}>
 			<p className="cursor-pointer py-1.5 font-bold grow-0 shrink overflow-hidden whitespace-normal text-sm pl-2">
 				{tc("projects:manage:suggest unity china to international migration")}
 			</p>
@@ -520,13 +516,13 @@ function ProjectViewHeader({
 
 	return (
 		<HNavBar
-			className={`${className}`}
-			commonClassName={"min-h-12"}
+			className={className}
 			leading={
 				<>
 					<Tooltip>
 						<TooltipTrigger asChild>
 							<Button
+								className={"compact:h-10"}
 								variant={"ghost"}
 								size={"sm"}
 								onClick={() => history.back()}
@@ -539,7 +535,7 @@ function ProjectViewHeader({
 						</TooltipContent>
 					</Tooltip>
 
-					<div className={"pl-2 space-y-0 my-1 shrink min-w-0"}>
+					<div className={"pl-2 space-y-0 shrink min-w-0 compact:pl-0"}>
 						<p className="cursor-pointer font-bold grow-0 whitespace-pre mb-0 leading-tight">
 							{projectName}
 						</p>
@@ -591,13 +587,6 @@ function ProjectViewHeader({
 	);
 }
 
-function projectGetCustomUnityArgs(projectPath: string) {
-	return queryOptions({
-		queryKey: ["projectGetCustomUnityArgs", projectPath],
-		queryFn: async () => await commands.projectGetCustomUnityArgs(projectPath),
-	});
-}
-
 function LaunchSettings({
 	defaultUnityArgs,
 	initialValue,
@@ -750,36 +739,37 @@ function ProjectButton({
 	};
 
 	return (
-		<>
-			<DropdownMenu>
-				<div className={"flex divide-x"}>
-					<OpenUnityButton
-						projectPath={projectPath}
-						unityVersion={unityVersion}
-						unityRevision={unityRevision}
-						className={"rounded-r-none pl-4 pr-3"}
-					/>
-					<DropdownMenuTrigger asChild className={"rounded-l-none pl-2 pr-2"}>
-						<Button>
-							<ChevronDown className={"w-4 h-4"} />
-						</Button>
-					</DropdownMenuTrigger>
-				</div>
-				<DropdownMenuContent>
-					<DropdownMenuContentBody
-						projectPath={projectPath}
-						removeProject={() => {
-							void openSingleDialog(RemoveProjectDialog, {
-								project: {
-									path: projectPath,
-									is_exists: true,
-								},
-							});
-						}}
-						onChangeLaunchOptions={onChangeLaunchOptions}
-					/>
-				</DropdownMenuContent>
-			</DropdownMenu>
-		</>
+		<DropdownMenu>
+			<div className={"flex divide-x"}>
+				<OpenUnityButton
+					projectPath={projectPath}
+					unityVersion={unityVersion}
+					unityRevision={unityRevision}
+					className={"rounded-r-none pl-4 pr-3 compact:h-10"}
+				/>
+				<DropdownMenuTrigger
+					asChild
+					className={"rounded-l-none pl-2 pr-2 compact:h-10"}
+				>
+					<Button>
+						<ChevronDown className={"w-4 h-4"} />
+					</Button>
+				</DropdownMenuTrigger>
+			</div>
+			<DropdownMenuContent>
+				<DropdownMenuContentBody
+					projectPath={projectPath}
+					removeProject={() => {
+						void openSingleDialog(RemoveProjectDialog, {
+							project: {
+								path: projectPath,
+								is_exists: true,
+							},
+						});
+					}}
+					onChangeLaunchOptions={onChangeLaunchOptions}
+				/>
+			</DropdownMenuContent>
+		</DropdownMenu>
 	);
 }
