@@ -2,9 +2,12 @@ import { Search } from "lucide-react";
 import type React from "react";
 import { useTranslation } from "react-i18next";
 import { Input } from "@/components/ui/input";
+import { cn } from "@/lib/utils";
 
 type SearchBoxProps = {
 	className?: string;
+	inputClassName?: string;
+	iconClassName?: string;
 	value?: string;
 	onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void;
 	ref?: React.Ref<HTMLInputElement>;
@@ -19,19 +22,23 @@ export const SearchBox = function SearchBox({
 	const { t } = useTranslation();
 
 	return (
-		<div className={`relative flex gap-2 ${className}`}>
-			{/* The search box */}
+		<div className={cn(`relative flex gap-2 h-10 compact:h-8`, className)}>
 			<Input
 				type="search"
 				placeholder={t("search:placeholder")}
-				className={
-					"w-full placeholder:text-primary focus:border-primary pl-9 placeholder:opacity-100"
-				}
+				className={`
+					w-full placeholder:text-primary focus:border-primary pl-9 placeholder:opacity-100
+					h-full compact:h-full
+				`}
 				value={value}
 				onChange={onChange}
 				ref={ref}
 			/>
-			<Search className="absolute! left-4 top-[17px]" width={13} height={14} />
+			<Search
+				className={`absolute! left-4 top-[calc(50%-7px)]`}
+				width={13}
+				height={14}
+			/>
 		</div>
 	);
 };
