@@ -12,7 +12,9 @@ export function VStack({
 	children: React.ReactNode;
 }) {
 	return (
-		<div className={`flex flex-col w-full gap-3 ${className}`}>{children}</div>
+		<div className={`flex flex-col w-full gap-3 compact:gap-2 ${className}`}>
+			{children}
+		</div>
 	);
 }
 
@@ -32,11 +34,13 @@ export function HNavBar({
 	trailingClassName?: string;
 }) {
 	return (
-		<Card className={`${className} mx-auto px-4 py-2 w-full`}>
-			<div className="mx-auto flex flex-wrap items-center justify-between text-primary gap-2">
+		<Card
+			className={`${className} shrink-0 mx-auto px-2 py-2 w-full compact:p-1`}
+		>
+			<div className="mx-auto flex flex-wrap items-center justify-between text-primary gap-2 w-full">
 				<div
 					className={cn(
-						"flex items-center gap-2 me-auto grow shrink",
+						"flex items-center gap-2 me-auto grow shrink h-full",
 						commonClassName,
 						leadingClassName,
 					)}
@@ -45,7 +49,7 @@ export function HNavBar({
 				</div>
 				<div
 					className={cn(
-						"flex items-center gap-2 ms-auto flex-wrap justify-end -mr-1",
+						"flex items-center gap-2 ms-auto flex-wrap justify-end h-full",
 						commonClassName,
 						trailingClassName,
 					)}
@@ -56,3 +60,11 @@ export function HNavBar({
 		</Card>
 	);
 }
+
+export function HNavBarText({ children }: { children?: React.ReactNode }) {
+	return (
+		<div className="-me-2 h-10 px-3 flex items-center grow-0">
+			<p className="cursor-pointer font-bold">{children}</p>
+		</div>
+	);
+}
