@@ -73,6 +73,8 @@ pub(crate) fn handlers() -> impl Fn(Invoke) -> bool + Send + Sync + 'static {
         environment::config::environment_set_logs_level,
         environment::config::environment_gui_animation,
         environment::config::environment_set_gui_animation,
+        environment::config::environment_gui_compact,
+        environment::config::environment_set_gui_compact,
         environment::config::environment_project_view_mode,
         environment::config::environment_set_project_view_mode,
         environment::config::environment_set_unity_hub_access_method,
@@ -178,6 +180,8 @@ pub(crate) fn export_ts() {
             environment::config::environment_set_logs_level,
             environment::config::environment_gui_animation,
             environment::config::environment_set_gui_animation,
+            environment::config::environment_gui_compact,
+            environment::config::environment_set_gui_compact,
             environment::config::environment_project_view_mode,
             environment::config::environment_set_project_view_mode,
             environment::config::environment_set_unity_hub_access_method,
